|
From: Tapio V. <aa...@us...> - 2010-01-07 12:20:53
|
Module: performous
Branch: master
Commit: 1e1ee53c7607f37143038c4502e11bfd97011fb5
Author: Tapio Vierros <tap...@gm...>
Date: Thu Jan 7 14:19:25 2010 +0200
Enable seeking in instrument songs, disable for dancing.
---
game/screen_sing.cc | 2 +-
1 files changed, 1 insertions(+), 1 deletions(-)
diff --git a/game/screen_sing.cc b/game/screen_sing.cc
index 0b9d598..59ecb06 100644
--- a/game/screen_sing.cc
+++ b/game/screen_sing.cc
@@ -253,7 +253,7 @@ void ScreenSing::manageEvent(SDL_Event event) {
if (key == SDLK_F4) ++config["audio/round-trip"];
if (key == SDLK_F5) --config["audio/controller_delay"];
if (key == SDLK_F6) ++config["audio/controller_delay"];
- if (m_song->track_map.empty()) { // Seeking is currently only permitted for karaoke songs
+ if (m_song->danceTracks.empty()) { // Seeking is currently not permitted for dance songs
bool seekback = false;
if (key == SDLK_HOME) { m_audio.seekPos(0.0); seekback = true; }
if (key == SDLK_LEFT) { m_audio.seek(-5.0); seekback = true; }
|